@@ -455,7 +455,18 @@ read_mlx_par_est <- function(path, x, ...) {
   sep <- ifelse(exists("sep", x), x$sep, ";")
   xx <- setDT(read.table(path, sep = sep, header = TRUE))
   if ("names" %in% names(x)) {
-    setnames(xx, seq_along(x[["names"]]), x[["names"]])
+    # This handles the case where the
+    nam <- x[["names"]]
+    do_more <- FALSE
+    if (length(nam) > ncol(xx)) {
+      nam <- nam[seq(1, ncol(xx))]
+    }
+    setnames(xx, seq_along(nam), nam)
+    if (do_more) {
+      nam <- x[["names"]]
+      nam <- nam[-seq(1, ncol(xx))]
+      xx <- xx[, (nam) := NA]
+    }
   }
   xx
 }
@@ -473,7 +484,8 @@ load_data_set <- function(x, path, sys, ...) {
   fpath <- file.path(path, x[["file"]])
   exists_file <- file.exists(fpath)
 
-  params <- as.list(match.call(expand.dots = TRUE))[-1]
+  params <- get_params_from_call()
+
   if (!exists_file) {
     ep <- list(...)$endpoint
     if (!is.null(ep) && !is.null(x$pattern)) {
